Visual working memory — BCI-Framework documentation

# Visual working memory

class `bci_framework.default_extensions.Visual_working_memory.main.` `VisualWorkingMemory`

  Visual working memory: change detection task.

  `_set_visible_markers`(visible: bool) → None

    Toggle the squares visibility.

  `build_markers`(shapes: int) → None

    Display the squares.

  `build_squares_area`() → None

    Create a space to positioning the squares.

  `build_trials`() → None

    Define the trials and pipeline trials.

    The trials consist (in this case) in a list of cues. The pipeline trials is a set of couples (callable, duration) that define a single trial, this list of functions are executed asynchronously and repeated for each trial.

  `clear`() → None

    Remove all elements from view.

  `cue`(cue: Literal[Right, Left], shapes: int, change: bool) → None

    Show the cue to indicate the hemifield target.

  `handle_response`(response: str) → None

    Capture the subject keyboard response.

  `memory_array`(cue: Literal[Right, Left], shapes: int, change: bool) → None

    Show the initial array.

  `prepare_shuffle`(cue: Literal[Right, Left], differences: int = 1) → None

    Makes sure of changing the color of the squares.

  `retention`(cue: Literal[Right, Left], shapes: int, change: bool) → None

    Remove the array.

  `soa`(cue: Literal[Right, Left], shapes: int, change: bool) → None

    Stimulus onset asynchronously.

  `start`()

    Start the run.

    A run consist in a consecutive trials execution.

  `stop`()

    Stop pipeline execution.

  `synchronizer`(value: bool) → None

    Show or hide synchronizer.

  `test_array`(cue: Literal[Right, Left], shapes: int, change: bool) → None

    Show the array again.

  `test_shapes`() → None

    Preview the size and distribution of the squares.